# PyDicts  [![PyPI - Downloads](https://img.shields.io/pypi/dm/pydicts?label=Pypi%20downloads)](https://pypi.org/project/pydicts/)
<div align="center">
  <div style="display: flex; align-items: flex-start;">
    <img src="https://github.com/turulomio/pydicts/blob/main/images/pydicts_jupyter.png?raw=true" width="150" title="PyDicts logo">
  </div>
Module to use dictionaries, list of dictionaries and other data structures 
</div>

## Links

- https://github.com/turulomio/pydicts/
- https://pypi.org/project/pydicts/

## Documentation

I've developed this module because I needed this kind of methods developing with Django and python

You can access documentation in [Pydicts Github page](https://turulomio.github.io/pydicts/)

